@@ -15,8 +15,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/tools/tags/release-0-10-0/compress_scumm_bun.cpp $
- * $Id: compress_scumm_bun.cpp 23086 2006-06-13 12:18:34Z eriktorbjorn $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/tools/tags/release-0-11-0/compress_scumm_bun.cpp $
+ * $Id: compress_scumm_bun.cpp 30460 2008-01-12 23:09:23Z sev $
  *
  */
 
@@ -614,7 +614,13 @@ int32 decompressCodec(int32 codec, byte *comp_input, byte *comp_output, int32 in
 }
 
 void showhelp(char *exename) {
-	printf("\nUsage: %s <inputfile> <inputdir> <outputdir> [--ogg] [encoder params]\n", exename);
+	printf("\nUsage: %s <inputfile> <inputdir> <outputdir> [params] [encoder params]\n", exename);
+
+	printf("\nParams:\n");
+	printf(" --mp3        encode to MP3 format (default)\n");
+	printf(" --vorbis     encode to Vorbis format\n");
+	printf(" --flac       encode to Flac format\n");
+
 	printf("\nMP3 mode params:\n");
 	printf(" -b <rate>    <rate> is the target bitrate(ABR)/minimal bitrate(VBR) (default:%d)\n", minBitrDef);
 	printf(" -B <rate>    <rate> is the maximum VBR/ABR bitrate (default:%d)\n", maxBitrDef);
@@ -630,6 +636,10 @@ void showhelp(char *exename) {
 	printf(" -M <rate>    <rate> is the maximum bitrate (default:unset)\n");
 	printf(" -q <value>   specifies the value (0 - 10) of VBR quality (10=best) (default:%d)\n", oggqualDef);
 	printf(" --silent     the output of oggenc is hidden (default:disabled)\n");
+
+	printf("\nFlac mode params:\n");
+	printf(" [params]     optional arguments passed directly to the encoder\n");
+
 	exit(2);
 }
 
@@ -645,6 +655,14 @@ static BundleAudioTable *bundleTable;
 static BundleAudioTable cbundleTable[10000]; // difficult to calculate
 static int32 cbundleCurIndex = 0;
 
+void encodeWaveWithFlac(char *filename) {
+	char fbuf[2048];
+	char fbuf2[2048];
+	sprintf(fbuf, "%s.wav", filename);
+	sprintf(fbuf2, "%s.fla", filename);
+	encodeAudio(fbuf, false, -1, fbuf2, kFlacMode);
+}
+
 void encodeWaveWithOgg(char *filename) {
 	char fbuf[2048];
 	char fbuf2[2048];
@@ -741,7 +759,7 @@ void writeToTempWave(char *fileName, byte *output_data, unsigned int size) {
 	_waveDataSize += size;
 }
 
-static bool _oggMode = false; // mp3 default
+static CompressMode gCompMode = kMP3Mode;
 
 typedef struct { int offset, size, codec; } CompTable;
 
@@ -900,24 +918,43 @@ void writeRegions(byte *ptr, int bits, int freq, int channels, char *dir, char *
 		writeWaveHeader(_waveDataSize, freq, channels);
 		free(outputData);
 		sprintf(tmpPath, "%s/%s_reg%03d", dir, filename, l);
-		if (_oggMode)
-			encodeWaveWithOgg(tmpPath);
-		else
+
+		switch (gCompMode) {
+		case kMP3Mode:
 			encodeWaveWithLame(tmpPath);
+			break;
+		case kVorbisMode:
+			encodeWaveWithOgg(tmpPath);
+			break;
+		case kFlacMode:
+			encodeWaveWithFlac(tmpPath);
+			break;
+		default:
+			error("Unknown encoding method");
+		}
+
 		sprintf(tmpPath, "%s/%s_reg%03d.wav", dir, filename, l);
 		unlink(tmpPath);
 
 		int32 startPos = ftell(output);
-		if (_oggMode)
-			sprintf(cbundleTable[cbundleCurIndex].filename, "%s_reg%03d.ogg", filename, l);
-		else
+		switch (gCompMode) {
+		case kMP3Mode:
 			sprintf(cbundleTable[cbundleCurIndex].filename, "%s_reg%03d.mp3", filename, l);
+			sprintf(tmpPath, "%s/%s_reg%03d.mp3", dir, filename, l);
+			break;
+		case kVorbisMode:
+			sprintf(cbundleTable[cbundleCurIndex].filename, "%s_reg%03d.ogg", filename, l);
+			sprintf(tmpPath, "%s/%s_reg%03d.ogg", dir, filename, l);
+			break;
+		case kFlacMode:
+			sprintf(cbundleTable[cbundleCurIndex].filename, "%s_reg%03d.fla", filename, l);
+			sprintf(tmpPath, "%s/%s_reg%03d.fla", dir, filename, l);
+			break;
+		default:
+			error("Unknown encoding method");
+		}
 		cbundleTable[cbundleCurIndex].offset = startPos;
 
-		if (_oggMode)
-			sprintf(tmpPath, "%s/%s_reg%03d.ogg", dir, filename, l);
-		else
-			sprintf(tmpPath, "%s/%s_reg%03d.mp3", dir, filename, l);
 		FILE *cmpFile = fopen(tmpPath, "rb");
 		fseek(cmpFile, 0, SEEK_END);
 		size = ftell(cmpFile);
@@ -1071,8 +1108,14 @@ int main(int argc, char *argv[]) {
 	if (argc > 4) {
 		i = 4;
 
-		if (strcmp(argv[i], "--ogg") == 0) {
-			_oggMode = true;
+		if (!strcmp(argv[i], "--mp3")) {
+			gCompMode = kMP3Mode;
+			i++;
+		} else if (!strcmp(argv[i], "--vorbis")) {
+			gCompMode = kVorbisMode;
+			i++;
+		} else if (!strcmp(argv[i], "--flac")) {
+			gCompMode = kFlacMode;
 			i++;
 		}
 
@@ -1088,15 +1131,28 @@ int main(int argc, char *argv[]) {
 				args[j] = argv[j];
 			args[j] = dummyName;
 		
-			int result;
+			switch (gCompMode) {
+			case kMP3Mode:
+				if (!process_mp3_parms(argc + 1, args, i)) {
+					showhelp(argv[0]);
+				}
 
-			if (_oggMode)
-				result = process_ogg_parms(argc + 1, args, i);
-			else
-				result = process_mp3_parms(argc + 1, args, i);
+				break;
+			case kVorbisMode:
+				if (!process_ogg_parms(argc + 1, args, i)) {
+					showhelp(argv[0]);
+				}
 
-			if (!result)
-				showhelp(argv[0]);
+				break;
+			case kFlacMode:
+				if (!process_flac_parms(argc + 1, args, i)){
+					showhelp(argv[0]);
+				}
+
+				break;
+			default:
+				error("Unknown encoding method");
+			}
 
 			free(args);
 		}
