@@ -16,8 +16,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/tools/tags/release-0-10-0/encode_dxa.cpp $
- * $Id: encode_dxa.cpp 24845 2006-12-11 22:52:34Z kirben $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/tools/tags/release-0-11-0/encode_dxa.cpp $
+ * $Id: encode_dxa.cpp 30460 2008-01-12 23:09:23Z sev $
  *
  */
 
@@ -25,7 +25,6 @@
 #include "util.h"
 
 #include <png.h>
-#include <zlib.h>
 
 const uint32 typeDEXA = 0x41584544;
 const uint32 typeFRAM = 0x4d415246;
@@ -650,7 +649,7 @@ void readVideoInfo(char *filename, int &width, int &height, int &framerate, int
 		width = readUint32LE(smk);
 		height = readUint32LE(smk);
 		framerate = readUint32LE(smk);
-	} else if (!memcmp(buf, "SMK2", 4)) {
+	} else if (!memcmp(buf, "SMK2", 4) || !memcmp(buf, "SMK4", 4)) {
 		uint32 flags;
 
 		width = readUint32LE(smk);
@@ -725,7 +724,6 @@ void showhelp(char *exename) {
 
 	printf("\nFlac mode params:\n");
 	printf(" [params]     optional arguments passed directly to the encoder\n");
-	printf("              recommended is: --best -b 1152\n");
 
 	printf("\n --help     this help message\n");
 
