@@ -15,8 +15,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/tools/tags/release-0-10-0/util.c $
- * $Id: util.c 23136 2006-06-15 14:34:46Z h00ligan $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/tools/tags/release-0-11-0/util.c $
+ * $Id: util.c 30460 2008-01-12 23:09:23Z sev $
  *
  */
 
@@ -62,6 +62,17 @@ void debug(int level, const char *s, ...) {
 	fprintf(stderr, "DEBUG: %s!\n", buf);
 }
 
+void notice(const char *s, ...) {
+	char buf[1024];
+	va_list va;
+
+	va_start(va, s);
+	vsnprintf(buf, 1024, s, va);
+	va_end(va);
+
+	fprintf(stdout, "%s\n", buf);
+}
+
 uint8 readByte(FILE *fp) {
 	return fgetc(fp);
 }
