@@ -15,8 +15,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/tools/tags/release-0-10-0/util.h $
- * $Id: util.h 23139 2006-06-15 16:58:09Z eriktorbjorn $
+ * $URL: https://scummvm.svn.sourceforge.net/svnroot/scummvm/tools/tags/release-0-11-0/util.h $
+ * $Id: util.h 30460 2008-01-12 23:09:23Z sev $
  *
  */
 
@@ -76,11 +76,10 @@ typedef uint8 bool;
 	#define snprintf _snprintf
 
 	#define SCUMM_LITTLE_ENDIAN
+	#pragma once
+	#pragma warning( disable : 4068 ) // turn off "unknown pragma" warning
+	#pragma warning( disable : 4996 ) // turn off warnings about unsafe functions
 
-	#define START_PACK_STRUCTS pack(push, 1)
-	#define END_PACK_STRUCTS   pack(pop)
-
-	
 #elif defined(__MINGW32__)
 
 	#define scumm_stricmp stricmp
@@ -88,14 +87,6 @@ typedef uint8 bool;
 
 	#define SCUMM_LITTLE_ENDIAN
 
-	#define START_PACK_STRUCTS pack(push, 1)
-	#define END_PACK_STRUCTS   pack(pop)
-
-
-	#ifndef _HEAPOK
-	#define _HEAPOK	(-2)
-	#endif
-
 #elif defined(UNIX)
 
 	#define scumm_stricmp strcasecmp
@@ -106,11 +97,6 @@ typedef uint8 bool;
 	#define SCUMM_NEED_ALIGNMENT
 	#endif
 
-	#if !defined(__GNUC__)
-	#define START_PACK_STRUCTS pack (1)
-	#define END_PACK_STRUCTS   pack ()
-	#endif
-
 #else
 
 	#error No system type defined
@@ -233,6 +219,7 @@ uint32 fileSize(FILE *fp);
 void NORETURN_PRE error(const char *s, ...) NORETURN_POST;
 void warning(const char *s, ...);
 void debug(int level, const char *s, ...);
+void notice(const char *s, ...);
 
 #if defined(__cplusplus)
 }
